# ScandiReddit

Construction of a Scandinavian Reddit dataset.

______________________________________________________________________
[![Documentation](https://img.shields.io/badge/docs-passing-green)](https://alexandrainst.github.io/ScandiReddit/scandi_reddit.html)
[![License](https://img.shields.io/github/license/alexandrainst/ScandiReddit)](https://github.com/alexandrainst/ScandiReddit/blob/main/LICENSE)
[![LastCommit](https://img.shields.io/github/last-commit/alexandrainst/ScandiReddit)](https://github.com/alexandrainst/ScandiReddit/commits/main)
[![Code Coverage](https://img.shields.io/badge/Coverage-0%25-red.svg)](https://github.com/alexandrainst/ScandiReddit/tree/main/tests)


Developers:

- Dan Saattrup Nielsen (dan.nielsen@alexandra.dk)


# Installation

The package is available on PyPI, so you can install the package using your favourite
package manager. For instance, `pip install scandi_reddit` or `poetry add
scandi_reddit`.


# Quick start

Simply run the command `build` in the terminal to build the dataset. This takes quite a
while! See `$ build --help` for more information on all the settings.
